@@ -4,23 +4,18 @@ package ORLite;
 
 use 5.006;
 use strict;
-use Carp           ();
-use File::Spec     ();
-use File::Temp     ();
-use File::Path     ();
-use File::Basename ();
-use Params::Util   qw{ _STRING _CLASS _HASHLIKE _CODELIKE };
-use DBI            ();
+use Carp                 ();
+use File::Spec      0.80 ();
+use File::Temp      0.20 ();
+use File::Path      2.04 ();
+use File::Basename     0 ();
+use Params::Util    0.33 qw{ _STRING _CLASS _HASHLIKE _CODELIKE };
+use DBI            1.607 ();
+use DBD::SQLite     1.25 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.20';
-
-	# DBD::SQLite has a bug that generates a spurious warning
-	# at compile time, so we need to temporarily disable them.
-	# Remove this hack once DBD::SQLite fixes the bug.
-	local $^W = 0;
-	require DBD::SQLite;
+	$VERSION = '1.21';
 }
 
 
@@ -112,6 +107,7 @@ sub import {
 package $pkg;
 
 use strict;
+use Carp ();
 
 my \$DBH = undef;
 
@@ -187,6 +183,16 @@ sub commit {
 	return 1;
 }
 
+sub commit_begin {
+	if ( \$DBH ) {
+		\$DBH->commit;
+		\$DBH->begin_work;
+	} else {
+		\$_[0]->begin;
+	}
+	return 1;
+}
+
 sub rollback {
 	\$DBH or return 1;
 	\$DBH->rollback;
@@ -195,14 +201,24 @@ sub rollback {
 	return 1;
 }
 
+sub rollback_begin {
+	if ( \$DBH ) {
+		\$DBH->rollback;
+		\$DBH->begin_work;
+	} else {
+		\$_[0]->begin;
+	}
+	return 1;
+}
+
 END_PERL
 
 	# Optionally generate the table classes
 	if ( $params{tables} ) {
 		# Capture the raw schema information
 		my $tables = $dbh->selectall_arrayref(
-			'select * from sqlite_master where type = ?',
-			{ Slice => {} }, 'table',
+			'select * from sqlite_master where name not like ? and type = ?',
+			{ Slice => {} }, 'sqlite_%', 'table',
 		);
 		foreach my $table ( @$tables ) {
 			$table->{columns} = $dbh->selectall_arrayref(
